==> 1.6.8.tar.gz: lib/xWidgetsBase.dart <==
library xwidgetbase;

import 'dart:io';
import 'dart:typed_data';

import 'package:dropdown_search/dropdown_search.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:image_picker/image_picker.dart';

import 'XStylesBase.dart';

part 'XWidgets/XCheckBoxWidget.dart';
part 'XWidgets/XContainerForImage.dart';
part 'XWidgets/XTreeNode.dart';
part 'XWidgets/XDrawer.dart';

part 'XWidgets/XBTN/XBtnBase.dart';
part 'XWidgets/XBTN/XBtnTakePhoto.dart';
part 'XWidgets/XBTN/XBtnReloader.dart';

part 'XWidgets/XItemsComplexWidgets/XItem.dart';
part 'XWidgets/XItemsComplexWidgets/XItemWidget.dart';

part 'XWidgets/XTextFormField/XTextFormField.dart';
part 'XWidgets/XTextFormField/XTextFormFieldLogin.dart';
part 'XWidgets/XTextFormField/XTextFormFieldWithLabel.dart';
part 'XWidgets/XTextFormField/XTextFormFieldWithContainer.dart';

part 'XWidgets/XWidgetsForText/XCardForText.dart';
part 'XWidgets/XWidgetsForText/XContainerWithLabel.dart';
part 'XWidgets/XWidgetsForText/XTextWithLabel.dart';

part 'XfXWidgets/XfxElenco.dart';
part 'XfXWidgets/XfxItemForList.dart';
part 'XfXWidgets/XfxScheda.dart';
part 'XfXWidgets/XfxSchedaTapped.dart';

part 'XfXWidgets/XfxElencoWidgets/XColFilter.dart';
part 'XfXWidgets/XfxElencoWidgets/XHeaderWithSorting.dart';

class XAlertDialog extends StatelessWidget {
  String? titleText;
  Function()? onPressedYes;
  Function()? onPressedNo;
  String? labelBTNyes;
  String? labelBTNno;
  Color? colorYes;
  Color? colorNo;
  Widget? childOfAlert;
  double? heightAlertDialog;
  final TextStyle? styleTitle;
  XAlertDialog({
    this.titleText,
    this.styleTitle,
    this.onPressedYes,
    this.onPressedNo,
    this.labelBTNyes,
    this.heightAlertDialog,
    this.labelBTNno,
    this.colorYes,
    this.colorNo,
    this.childOfAlert,
  });

  @override
  Widget build(BuildContext context) {
    return AlertDialog(
        backgroundColor: Colors.grey[800],
        title: Container(
            height: heightAlertDialog ?? 400,
            child: Column(
              children: [titleText != null ? Text(titleText ?? 'Hai cambiato dei dati cosa vuoi fare?', style: styleTitle ?? XStyles.xStyleText(fontSize: 19)) : Text(titleText ?? ""), childOfAlert != null ? Container(child: childOfAlert) : Container(height: 1)],
            )),
        content: Row(mainAxisAlignment: MainAxisAlignment.spaceAround, children: [
          Expanded(child: Container(child: TextButton(onPressed: onPressedNo, child: Text(labelBTNno ?? "NON LI SALVO", style: TextStyle(color: colorNo ?? Colors.redAccent))))),
          Expanded(child: Container(child: TextButton(onPressed: onPressedYes, child: Text(labelBTNyes ?? "LI SALVO", style: TextStyle(color: colorYes ?? Colors.greenAccent))))),
        ]));
  }
}

class XSearchBar extends StatelessWidget {
  final Function()? onPressed;
  final TextEditingController? controller;
  final String? labelText;
  final Color? iconColor;
  final Color? borderColor;
  final String? hintText;
  final TextStyle? hintStyle;
  final TextStyle? labelStyle;
  final Widget? iconForSearch;
  final InputBorder? enabledBorder;
  final InputBorder? disabledBorder;
  final InputBorder? border;
  XSearchBar({
    this.labelText,
    this.controller,
    this.onPressed,
    this.iconColor,
    this.borderColor,
    this.hintText,
    this.hintStyle,
    this.labelStyle,
    this.iconForSearch,
    this.enabledBorder,
    this.disabledBorder,
    this.border,
  });

  @override
  Widget build(BuildContext context) {
    return Row(
      children: <Widget>[
        Expanded(
          child: Container(
            child: Padding(
              padding: const EdgeInsets.all(8.0),
              child: TextField(
                // focusNode: searchFocus,
                controller: controller,
                decoration: InputDecoration(
                    suffixIcon: IconButton(
                        onPressed: () {
                          controller!.clear();
                        },
                        icon: iconForSearch ?? Icon(Icons.clear),
                        color: iconColor ?? Colors.black),
                    labelText: labelText ?? "Cerca",
                    hintText: hintText ?? "Cerca",
                    hintStyle: hintStyle ?? XStyles.xStyTextForDescr(Colors.black),
                    labelStyle: labelStyle ?? XStyles.xStyTextForLabel(Colors.black),
                    enabledBorder: enabledBorder ?? OutlineInputBorder(borderSide: BorderSide(color: borderColor ?? Colors.black), borderRadius: BorderRadius.all(Radius.circular(25.0))),
                    disabledBorder: disabledBorder ?? OutlineInputBorder(borderSide: BorderSide(color: borderColor ?? Colors.black), borderRadius: BorderRadius.all(Radius.circular(25.0))),
                    border: border ?? OutlineInputBorder(borderSide: BorderSide(color: borderColor ?? Colors.black), borderRadius: BorderRadius.all(Radius.circular(25.0)))),
              ),
            ),
          ),
        ),
      ],
    );
  }
}

class XCircularProgressIndicator extends StatelessWidget {
  final String? label;
  final IconData? icon;
  XCircularProgressIndicator({
    this.label,
    this.icon,
  });

  @override
  Widget build(BuildContext context) {
    return Center(child: SizedBox(child: CircularProgressIndicator(strokeWidth: 8), height: 200.0, width: 200.0));
  }
}

==> 1.7.0.tar.gz: lib/xWidgetsBase.dart <==
library xwidgetbase;

import 'dart:io';
import 'dart:typed_data';

import 'package:dropdown_search/dropdown_search.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:image_picker/image_picker.dart';

import 'XStylesBase.dart';

part 'XWidgets/XCheckBoxWidget.dart';
part 'XWidgets/XContainerForImage.dart';
part 'XWidgets/XTreeNode.dart';
part 'XWidgets/XDrawer.dart';

part 'XWidgets/XBTN/XBtnBase.dart';
part 'XWidgets/XBTN/XBtnTakePhoto.dart';
part 'XWidgets/XBTN/XBtnReloader.dart';

part 'XWidgets/XItemsComplexWidgets/XItem.dart';
part 'XWidgets/XItemsComplexWidgets/XItemWidget.dart';

part 'XWidgets/XTextFormField/XTextFormField.dart';
part 'XWidgets/XTextFormField/XTextFormFieldLogin.dart';
part 'XWidgets/XTextFormField/XTextFormFieldWithLabel.dart';
part 'XWidgets/XTextFormField/XTextFormFieldWithContainer.dart';

part 'XWidgets/XWidgetsForText/XCardForText.dart';
part 'XWidgets/XWidgetsForText/XContainerWithLabel.dart';
part 'XWidgets/XWidgetsForText/XTextWithLabel.dart';

part 'XfXWidgets/XfxElenco.dart';
part 'XfXWidgets/XfxItemForList.dart';
part 'XfXWidgets/XfxScheda.dart';
part 'XfXWidgets/XfxSchedaTapped.dart';

part 'XfXWidgets/XfxElencoWidgets/XColFilter.dart';
part 'XfXWidgets/XfxElencoWidgets/XHeaderWithSorting.dart';

class XAlertDialog extends StatelessWidget {
  String? titleText;
  Function()? onPressedYes;
  Function()? onPressedNo;
  String? labelBTNyes;
  String? labelBTNno;
  Color? colorYes;
  Color? colorNo;
  Widget? childOfAlert;
  double? heightAlertDialog;
  final TextStyle? styleTitle;
  XAlertDialog({
    this.titleText,
    this.styleTitle,
    this.onPressedYes,
    this.onPressedNo,
    this.labelBTNyes,
    this.heightAlertDialog,
    this.labelBTNno,
    this.colorYes,
    this.colorNo,
    this.childOfAlert,
  });

  @override
  Widget build(BuildContext context) {
    return AlertDialog(
        backgroundColor: Colors.grey[800],
        title: Container(
            height: heightAlertDialog ?? 400,
            child: Column(
              children: [titleText != null ? Text(titleText ?? 'Hai cambiato dei dati cosa vuoi fare?', style: styleTitle ?? XStyles.xStyleText(fontSize: 19)) : Text(titleText ?? ""), childOfAlert != null ? Container(child: childOfAlert) : Container(height: 1)],
            )),
        content: Row(mainAxisAlignment: MainAxisAlignment.spaceAround, children: [
          Expanded(child: Container(child: TextButton(onPressed: onPressedNo, child: Text(labelBTNno ?? "NON LI SALVO", style: TextStyle(color: colorNo ?? Colors.redAccent))))),
          Expanded(child: Container(child: TextButton(onPressed: onPressedYes, child: Text(labelBTNyes ?? "LI SALVO", style: TextStyle(color: colorYes ?? Colors.greenAccent))))),
        ]));
  }
}

class XSearchBar extends StatelessWidget {
  final Function()? onPressed;
  final TextEditingController? controller;
  final String? labelText;
  final Color? iconColor;
  final Color? borderColor;
  final String? hintText;
  final TextStyle? hintStyle;
  final TextStyle? labelStyle;
  final Widget? iconForSearch;
  final InputBorder? enabledBorder;
  final InputBorder? disabledBorder;
  final InputBorder? border;
  final FocusNode? searchFocus;
  final bool autoFocus;
  final Function(String)? onTextChanged;
  final Function()? onPressedClear;
  final Color? colorOfSearchBox;
  XSearchBar({
    this.labelText,
    this.controller,
    this.onPressed,
    this.iconColor,
    this.borderColor,
    this.hintText,
    this.hintStyle,
    this.labelStyle,
    this.iconForSearch,
    this.enabledBorder,
    this.disabledBorder,
    this.border,
    this.searchFocus,
    this.onTextChanged,
    this.onPressedClear,
    this.colorOfSearchBox,
    this.autoFocus = true,
  });

  @override
  Widget build(BuildContext context) {
    return Row(
      children: <Widget>[
        Expanded(
          child: Container(
            color: colorOfSearchBox ?? Colors.transparent,
            child: Padding(
              padding: const EdgeInsets.all(8.0),
              child: TextField(
                focusNode: searchFocus,
                autofocus: autoFocus,
                onChanged: onTextChanged,
                controller: controller,
                decoration: InputDecoration(
                    suffixIcon: IconButton(
                        onPressed: onPressedClear ??
                            () {
                              controller!.clear();
                            },
                        icon: iconForSearch ?? Icon(Icons.clear),
                        color: iconColor ?? Colors.black),
                    labelText: labelText ?? "Cerca",
                    hintText: hintText ?? "Cerca",
                    hintStyle: hintStyle ?? XStyles.xStyTextForDescr(Colors.black),
                    labelStyle: labelStyle ?? XStyles.xStyTextForLabel(Colors.black),
                    enabledBorder: enabledBorder ?? OutlineInputBorder(borderSide: BorderSide(color: borderColor ?? Colors.black), borderRadius: BorderRadius.all(Radius.circular(25.0))),
                    disabledBorder: disabledBorder ?? OutlineInputBorder(borderSide: BorderSide(color: borderColor ?? Colors.black), borderRadius: BorderRadius.all(Radius.circular(25.0))),
                    border: border ?? OutlineInputBorder(borderSide: BorderSide(color: borderColor ?? Colors.black), borderRadius: BorderRadius.all(Radius.circular(25.0)))),
              ),
            ),
          ),
        ),
      ],
    );
  }
}

class XCircularProgressIndicator extends StatelessWidget {
  final String? label;
  final IconData? icon;
  XCircularProgressIndicator({
    this.label,
    this.icon,
  });

  @override
  Widget build(BuildContext context) {
    return Center(child: SizedBox(child: CircularProgressIndicator(strokeWidth: 8), height: 200.0, width: 200.0));
  }
}
